/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebDatabaseManagerProxyMessages_h
#define WebDatabaseManagerProxyMessages_h

#include "Arguments.h"
#include "MessageEncoder.h"
#include "OriginAndDatabases.h"
#include "StringReference.h"
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>

namespace WTF {
    class String;
}

namespace Messages {
namespace WebDatabaseManagerProxy {

static inline IPC::StringReference messageReceiverName()
{
    return IPC::StringReference("WebDatabaseManagerProxy");
}

class DidGetDatabasesByOrigin {
public:
    typedef std::tuple<Vector<WebKit::OriginAndDatabases>, uint64_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidGetDatabasesByOrigin"); }
    static const bool isSync = false;

    DidGetDatabasesByOrigin(const Vector<WebKit::OriginAndDatabases>& originAndDatabases, uint64_t callbackID)
        : m_arguments(originAndDatabases, callbackID)
    {
    }

    const std::tuple<const Vector<WebKit::OriginAndDatabases>&, uint64_t>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const Vector<WebKit::OriginAndDatabases>&, uint64_t> m_arguments;
};

class DidGetDatabaseOrigins {
public:
    typedef std::tuple<Vector<String>, uint64_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidGetDatabaseOrigins"); }
    static const bool isSync = false;

    DidGetDatabaseOrigins(const Vector<String>& originIdentifiers, uint64_t callbackID)
        : m_arguments(originIdentifiers, callbackID)
    {
    }

    const std::tuple<const Vector<String>&, uint64_t>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const Vector<String>&, uint64_t> m_arguments;
};

class DidModifyOrigin {
public:
    typedef std::tuple<String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidModifyOrigin"); }
    static const bool isSync = false;

    explicit DidModifyOrigin(const String& originIdentifier)
        : m_arguments(originIdentifier)
    {
    }

    const std::tuple<const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const String&> m_arguments;
};

class DidModifyDatabase {
public:
    typedef std::tuple<String, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidModifyDatabase"); }
    static const bool isSync = false;

    DidModifyDatabase(const String& originIdentifier, const String& databaseIdentifier)
        : m_arguments(originIdentifier, databaseIdentifier)
    {
    }

    const std::tuple<const String&, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const String&, const String&> m_arguments;
};

} // namespace WebDatabaseManagerProxy
} // namespace Messages

#endif // WebDatabaseManagerProxyMessages_h
