/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebIDBServerConnectionMessages_h
#define WebIDBServerConnectionMessages_h

#if ENABLE(INDEXED_DATABASE) && ENABLE(DATABASE_PROCESS)

#include "Arguments.h"
#include "MessageEncoder.h"
#include "StringReference.h"

namespace IPC {
    class DataReference;
}

namespace WTF {
    class String;
}

namespace WebCore {
    struct IDBKeyData;
    struct IDBGetResult;
    struct IDBDatabaseMetadata;
}

namespace Messages {
namespace WebIDBServerConnection {

static inline IPC::StringReference messageReceiverName()
{
    return IPC::StringReference("WebIDBServerConnection");
}

class DidGetOrEstablishIDBDatabaseMetadata {
public:
    typedef std::tuple<uint64_t, bool, WebCore::IDBDatabaseMetadata> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidGetOrEstablishIDBDatabaseMetadata"); }
    static const bool isSync = false;

    DidGetOrEstablishIDBDatabaseMetadata(uint64_t requestID, bool success, const WebCore::IDBDatabaseMetadata& metadata)
        : m_arguments(requestID, success, metadata)
    {
    }

    const std::tuple<uint64_t, bool, const WebCore::IDBDatabaseMetadata&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool, const WebCore::IDBDatabaseMetadata&> m_arguments;
};

class DidDeleteDatabase {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidDeleteDatabase"); }
    static const bool isSync = false;

    DidDeleteDatabase(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidOpenTransaction {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidOpenTransaction"); }
    static const bool isSync = false;

    DidOpenTransaction(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidBeginTransaction {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidBeginTransaction"); }
    static const bool isSync = false;

    DidBeginTransaction(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidCommitTransaction {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidCommitTransaction"); }
    static const bool isSync = false;

    DidCommitTransaction(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidResetTransaction {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidResetTransaction"); }
    static const bool isSync = false;

    DidResetTransaction(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidRollbackTransaction {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidRollbackTransaction"); }
    static const bool isSync = false;

    DidRollbackTransaction(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidChangeDatabaseVersion {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidChangeDatabaseVersion"); }
    static const bool isSync = false;

    DidChangeDatabaseVersion(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidCreateObjectStore {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidCreateObjectStore"); }
    static const bool isSync = false;

    DidCreateObjectStore(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidDeleteObjectStore {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidDeleteObjectStore"); }
    static const bool isSync = false;

    DidDeleteObjectStore(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidClearObjectStore {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidClearObjectStore"); }
    static const bool isSync = false;

    DidClearObjectStore(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidCreateIndex {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidCreateIndex"); }
    static const bool isSync = false;

    DidCreateIndex(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidDeleteIndex {
public:
    typedef std::tuple<uint64_t, bool> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidDeleteIndex"); }
    static const bool isSync = false;

    DidDeleteIndex(uint64_t requestID, bool success)
        : m_arguments(requestID, success)
    {
    }

    const std::tuple<uint64_t, bool>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, bool> m_arguments;
};

class DidPutRecord {
public:
    typedef std::tuple<uint64_t, WebCore::IDBKeyData, uint32_t, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidPutRecord"); }
    static const bool isSync = false;

    DidPutRecord(uint64_t requestID, const WebCore::IDBKeyData& resultKey, uint32_t errorCode, const String& errorMessage)
        : m_arguments(requestID, resultKey, errorCode, errorMessage)
    {
    }

    const std::tuple<uint64_t, const WebCore::IDBKeyData&, uint32_t, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, const WebCore::IDBKeyData&, uint32_t, const String&> m_arguments;
};

class DidGetRecord {
public:
    typedef std::tuple<uint64_t, WebCore::IDBGetResult, uint32_t, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidGetRecord"); }
    static const bool isSync = false;

    DidGetRecord(uint64_t requestID, const WebCore::IDBGetResult& getResult, uint32_t errorCode, const String& errorMessage)
        : m_arguments(requestID, getResult, errorCode, errorMessage)
    {
    }

    const std::tuple<uint64_t, const WebCore::IDBGetResult&, uint32_t, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, const WebCore::IDBGetResult&, uint32_t, const String&> m_arguments;
};

class DidOpenCursor {
public:
    typedef std::tuple<uint64_t, int64_t, WebCore::IDBKeyData, WebCore::IDBKeyData, IPC::DataReference, uint32_t, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidOpenCursor"); }
    static const bool isSync = false;

    DidOpenCursor(uint64_t requestID, int64_t cursorID, const WebCore::IDBKeyData& key, const WebCore::IDBKeyData& primaryKey, const IPC::DataReference& value, uint32_t errorCode, const String& errorMessage)
        : m_arguments(requestID, cursorID, key, primaryKey, value, errorCode, errorMessage)
    {
    }

    const std::tuple<uint64_t, int64_t, const WebCore::IDBKeyData&, const WebCore::IDBKeyData&, const IPC::DataReference&, uint32_t, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, int64_t, const WebCore::IDBKeyData&, const WebCore::IDBKeyData&, const IPC::DataReference&, uint32_t, const String&> m_arguments;
};

class DidAdvanceCursor {
public:
    typedef std::tuple<uint64_t, WebCore::IDBKeyData, WebCore::IDBKeyData, IPC::DataReference, uint32_t, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidAdvanceCursor"); }
    static const bool isSync = false;

    DidAdvanceCursor(uint64_t requestID, const WebCore::IDBKeyData& key, const WebCore::IDBKeyData& primaryKey, const IPC::DataReference& value, uint32_t errorCode, const String& errorMessage)
        : m_arguments(requestID, key, primaryKey, value, errorCode, errorMessage)
    {
    }

    const std::tuple<uint64_t, const WebCore::IDBKeyData&, const WebCore::IDBKeyData&, const IPC::DataReference&, uint32_t, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, const WebCore::IDBKeyData&, const WebCore::IDBKeyData&, const IPC::DataReference&, uint32_t, const String&> m_arguments;
};

class DidIterateCursor {
public:
    typedef std::tuple<uint64_t, WebCore::IDBKeyData, WebCore::IDBKeyData, IPC::DataReference, uint32_t, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidIterateCursor"); }
    static const bool isSync = false;

    DidIterateCursor(uint64_t requestID, const WebCore::IDBKeyData& key, const WebCore::IDBKeyData& primaryKey, const IPC::DataReference& value, uint32_t errorCode, const String& errorMessage)
        : m_arguments(requestID, key, primaryKey, value, errorCode, errorMessage)
    {
    }

    const std::tuple<uint64_t, const WebCore::IDBKeyData&, const WebCore::IDBKeyData&, const IPC::DataReference&, uint32_t, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, const WebCore::IDBKeyData&, const WebCore::IDBKeyData&, const IPC::DataReference&, uint32_t, const String&> m_arguments;
};

class DidCount {
public:
    typedef std::tuple<uint64_t, int64_t, uint32_t, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidCount"); }
    static const bool isSync = false;

    DidCount(uint64_t requestID, int64_t count, uint32_t errorCode, const String& errorMessage)
        : m_arguments(requestID, count, errorCode, errorMessage)
    {
    }

    const std::tuple<uint64_t, int64_t, uint32_t, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, int64_t, uint32_t, const String&> m_arguments;
};

class DidDeleteRange {
public:
    typedef std::tuple<uint64_t, uint32_t, String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidDeleteRange"); }
    static const bool isSync = false;

    DidDeleteRange(uint64_t requestID, uint32_t errorCode, const String& errorMessage)
        : m_arguments(requestID, errorCode, errorMessage)
    {
    }

    const std::tuple<uint64_t, uint32_t, const String&>& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<uint64_t, uint32_t, const String&> m_arguments;
};

} // namespace WebIDBServerConnection
} // namespace Messages

#endif // ENABLE(INDEXED_DATABASE) && ENABLE(DATABASE_PROCESS)

#endif // WebIDBServerConnectionMessages_h
